@@ -1416,11 +1416,7 @@ xfconf_channel_get_array_valist(XfconfChannel *channel,
 
         switch(cur_value_type) {
             HANDLE_CASE(guchar, UCHAR, uchar)
-#if GLIB_CHECK_VERSION (2, 32, 0)
             HANDLE_CASE(gchar, CHAR, schar)
-#else
-            HANDLE_CASE(gchar, CHAR, char)
-#endif
             HANDLE_CASE(guint32, UINT, uint)
             HANDLE_CASE(gint32, INT, int)
             HANDLE_CASE(guint64, UINT64, uint64)
@@ -1596,11 +1592,7 @@ xfconf_channel_set_array_valist(XfconfChannel *channel,
 
         switch(cur_value_type) {
             HANDLE_CASE(guchar, UCHAR, uchar)
-#if GLIB_CHECK_VERSION (2, 32, 0)
             HANDLE_CASE(gchar, CHAR, schar)
-#else
-            HANDLE_CASE(gchar, CHAR, char)
-#endif
             HANDLE_CASE(guint32, UINT, uint)
             HANDLE_CASE(gint32, INT, int)
             HANDLE_CASE(guint64, UINT64, uint64)
@@ -1933,13 +1925,8 @@ xfconf_channel_get_structv(XfconfChannel *channel,
                 break;
 
             case G_TYPE_CHAR:
-#if GLIB_CHECK_VERSION (2, 32, 0)
                 SET_STRUCT_VAL(gchar, G_TYPE_CHAR, ALIGNOF_GCHAR,
                                g_value_get_schar);
-#else
-                SET_STRUCT_VAL(gchar, G_TYPE_CHAR, ALIGNOF_GCHAR,
-                               g_value_get_char);
-#endif
                 break;
 
             case G_TYPE_UINT:
@@ -2157,13 +2144,8 @@ xfconf_channel_set_structv(XfconfChannel *channel,
                 break;
 
             case G_TYPE_CHAR:
-#if GLIB_CHECK_VERSION (2, 32, 0)
                 GET_STRUCT_VAL(gchar, G_TYPE_CHAR, ALIGNOF_GCHAR,
                                g_value_set_schar);
-#else
-                GET_STRUCT_VAL(gchar, G_TYPE_CHAR, ALIGNOF_GCHAR,
-                               g_value_set_char);
-#endif
                 break;
 
             case G_TYPE_UINT:
